from browser import document, window, ajax, alert, prompt, confirm, html
import json


def insert_this_in_that(*, this_id: str = None,
                        this_template: str = None,
                        that_id: str = None,
                        that_element=None):
    """
    inserts this.html in that
    :param this_template: element html template received from django view render function
    :param this_id: id of element who's inner html will be inserted into that_id element
    :param that_id: where this_id's inner html will be inserted
    :param that_element: Element object from the document
    :return:
    """
    if this_id:
        try:
            this = document[this_id].html
        except KeyError as e:
            # insert a false this
            this = '<div id="falseDIv"><small>Something is happening...</small></div>'
    else:
        this = this_template
    # register an element on document
    insert_this = document.createElement('div')
    insert_this.html = this

    if that_id:
        document[that_id].clear()
        document[that_id].appendChild(insert_this)
    if that_element:
        that_element.clear()
        that_element.appendChild(insert_this)
    del insert_this


def post_it(*, url, data: dict, on_complete: callable):
    url = url
    headers = {"Content-Type": "application/json", "X-CSRFToken": window.CSRF_TOKEN}
    data = data
    ajax.post(url, headers=headers, data=json.dumps(data), oncomplete=on_complete)


class TempStorageObject:
    pass


tso = TempStorageObject()


# ---------------------- ACTIONS/EVENTS --------
def aa_act_on_offer_filter_change(event,
                                  selected_categories,
                                  selected_products,
                                  selected_offer_types):
    # ------ ADOBE ANALYTICS related ---
    # build data-event-dict-aa value for adobe analytics
    # first build the dict out of the existing str
    existing_data_event_dict_aa = json.loads(event.currentTarget.getAttribute(
             'data-event-dict-aa'))
    required_data_event_dict_aa = {
        'categories': selected_categories,
        'products': selected_products,
        'offer_types': selected_offer_types
    }
    existing_data_event_dict_aa.update(required_data_event_dict_aa)
    # update data-event-dict-aa string
    event.currentTarget.setAttribute('data-event-dict-aa', json.dumps(
        existing_data_event_dict_aa))
    # manually call on_click_on_analytic_target_element from base.py
    window.on_click_on_analytic_target_element(event, True)


def get_form_data(event):
    form = event.currentTarget
    # first run the adobe analytics event layer
    selected_categories = [
        checkbox.getAttribute('data-name') for checkbox in
        form.select('#categoryCheckboxes input')
        if checkbox.checked
        ]
    selected_products = [
        child.getAttribute('data-name') for child in
         document['productSelect'].children if
         child.selected and not child.disabled
    ]
    selected_offer_type= [
        checkbox.getAttribute('data-name') for checkbox in
        form.select('#offerTypeRadioButtons input')
        if checkbox.checked
    ]
    aa_act_on_offer_filter_change(event, selected_categories, selected_products, selected_offer_type)
    # submit form
    form.requestSubmit()



# bind events ['click', 'change', 'on hover' ect.]
def bind_change_on_offer_filter_form(unbind=False):
    target_select = document['offerFilterForm']
    if not unbind:
        target_select.bind("change", get_form_data)
    else:
        target_select.unbind("change", get_form_data)


# call default event bindings
bind_change_on_offer_filter_form()
